@@ -1,7 +1,7 @@
 """Define a SimpliSafe system (attached to a location)."""
 import logging
 from enum import Enum
-from typing import Dict, Union
+from typing import Dict, Union  # noqa, pylint: disable=unused-import
 
 from .sensor import SensorV2, SensorV3
 from .util.string import convert_to_underscore
@@ -13,10 +13,12 @@ class SystemStates(Enum):
     """Define states that the system can be in."""
 
     away = 1
-    entry_delay = 2
-    exit_delay = 3
-    home = 4
-    off = 5
+    away_count = 2
+    entry_delay = 3
+    exit_delay = 4
+    home = 5
+    home_count = 5
+    off = 6
     unknown = 99
 
 
@@ -56,6 +58,11 @@ class System:
         """Return the SimpliSafe identifier for this system."""
         return self._location_info['sid']
 
+    @property
+    def temperature(self) -> int:
+        """Return the overall temperature measured by the system."""
+        return self._location_info['system']['temperature']
+
     @property
     def version(self) -> int:
         """Return the system version."""
